With LinchPin, resources are king. Defining, managing, and generating outputs are all done using a declarative syntax. Resources are managed via the :term:`PinFile`. The PinFile can hold two additional files, the :term:`topology`, and :term:`layout`. Linchpin also supports :doc:`hooks`.

Topology
````````

.. include:: includes/topologies.rst

Inventory Layout
````````````````

.. include:: includes/layouts.rst


PinFile
```````

.. include:: gs/pinfile.rst


